@@ -1,25 +1,22 @@
 """Firmware update helper."""
 import asyncio
-from typing import Dict, Optional
+from typing import Dict, List, Optional, cast
 
 import aiohttp
 
 from .client import Client
+from .model.firmware import FirmwareUpdateData
 from .model.node import Node
-from .util.helpers import convert_bytes_to_base64
 
 
-async def begin_firmware_update(
+async def update_firmware(
     url: str,
     node: Node,
-    filename: str,
-    file: bytes,
+    updates: List[FirmwareUpdateData],
     session: aiohttp.ClientSession,
     additional_user_agent_components: Optional[Dict[str, str]] = None,
-    file_format: Optional[str] = None,
-    target: Optional[int] = None,
-) -> None:
-    """Send beginFirmwareUpdate command to Node."""
+) -> bool:
+    """Send updateFirmware command to Node."""
     client = Client(
         url, session, additional_user_agent_components=additional_user_agent_components
     )
@@ -29,18 +26,49 @@ async def begin_firmware_update(
     receive_task = asyncio.get_running_loop().create_task(client.receive_until_closed())
 
     cmd = {
-        "command": "node.begin_firmware_update",
+        "command": "node.update_firmware",
         "nodeId": node.node_id,
-        "firmwareFilename": filename,
-        "firmwareFile": convert_bytes_to_base64(file),
+        "updates": [update.to_dict() for update in updates],
     }
-    if file_format is not None:
-        cmd["firmwareFileFormat"] = file_format
 
-    if target is not None:
-        cmd["target"] = target
-
-    await client.async_send_command(cmd, require_schema=18)
+    data = await client.async_send_command(cmd, require_schema=24)
     await client.disconnect()
     if not receive_task.done():
         receive_task.cancel()
+
+    return cast(bool, data["success"])
+
+
+async def controller_firmware_update_otw(
+    url: str,
+    firmware_file: FirmwareUpdateData,
+    session: aiohttp.ClientSession,
+    additional_user_agent_components: Optional[Dict[str, str]] = None,
+) -> bool:
+    """
+    Send firmwareUpdateOTW command to Controller.
+
+    Sending the wrong firmware to a controller can brick it and make it unrecoverable.
+    Consumers of this library should build mechanisms to ensure that users understand
+    the risks.
+    """
+    client = Client(
+        url, session, additional_user_agent_components=additional_user_agent_components
+    )
+    await client.connect()
+    await client.initialize()
+
+    receive_task = asyncio.get_running_loop().create_task(client.receive_until_closed())
+
+    data = await client.async_send_command(
+        {
+            "command": "controller.firmware_update_otw",
+            **firmware_file.to_dict(),
+        },
+        require_schema=25,
+    )
+    await client.disconnect()
+    if not receive_task.done():
+        receive_task.cancel()
+
+    return cast(bool, data["success"])
