@@ -14,6 +14,15 @@ else:
     from typing import TypedDict
 
 
+class FoundNodeDataType(TypedDict, total=False):
+    """Represent a found node data dict type."""
+
+    nodeId: int
+    deviceClass: DeviceClassDataType
+    supportedCCs: List[int]
+    controlledCCs: List[int]
+
+
 class NodeDataType(TypedDict, total=False):
     """Represent a node data dict type."""
 
